@@ -11,14 +11,23 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import imp
-import mock
+import importlib
 import os
+import sys
+from unittest import mock
+
 from oslotest import base
 
-module_path = (os.path.dirname(os.path.realpath(__file__)) +
-               '/../static/usr/local/sbin/growvols')
-growvols = imp.load_source('growvols', module_path)
+
+importlib.machinery.SOURCE_SUFFIXES.append('')
+file_path = (os.path.dirname(os.path.realpath(__file__)) +
+             '/../static/usr/local/sbin/growvols')
+spec = importlib.util.spec_from_file_location('growvols', file_path)
+module = importlib.util.module_from_spec(spec)
+spec.loader.exec_module(module)
+sys.modules['growvols'] = module
+growvols = module
+importlib.machinery.SOURCE_SUFFIXES.pop()
 
 # output of lsblk -Po kname,pkname,name,label,type,fstype,mountpoint
 LSBLK = """KNAME="sda" PKNAME="" NAME="sda" LABEL="" TYPE="disk" FSTYPE="" MOUNTPOINT=""
@@ -717,7 +726,7 @@ class TestGrowvols(base.BaseTestCase):
             mock.call(['sgdisk', '--new=5:79267840:488265727',
                        '--change-name=5:growvols', '/dev/sda']),
             mock.call(['partprobe']),
-            mock.call(['pvcreate', '/dev/sda5']),
+            mock.call(['pvcreate', '-ff', '--yes', '/dev/sda5']),
             mock.call(['vgextend', 'vg', '/dev/sda5']),
             mock.call(['lvextend', '--size', '+209404821504B',
                        '/dev/mapper/vg-lv_root', '/dev/sda5']),
@@ -748,7 +757,7 @@ class TestGrowvols(base.BaseTestCase):
             mock.call(['sgdisk', '--new=5:79267840:488265727',
                        '--change-name=5:growvols', '/dev/sda']),
             mock.call(['partprobe']),
-            mock.call(['pvcreate', '/dev/sda5']),
+            mock.call(['pvcreate', '-ff', '--yes', '/dev/sda5']),
             mock.call(['vgextend', 'vg', '/dev/sda5']),
             mock.call(['lvextend', '--size', '+41880125440B',
                        '/dev/mapper/vg-lv_home', '/dev/sda5']),
@@ -819,7 +828,7 @@ class TestGrowvols(base.BaseTestCase):
             mock.call(['sgdisk', '--new=5:79267840:488265727',
                        '--change-name=5:growvols', '/dev/sda']),
             mock.call(['partprobe']),
-            mock.call(['pvcreate', '/dev/sda5']),
+            mock.call(['pvcreate', '-ff', '--yes', '/dev/sda5']),
             mock.call(['vgextend', 'vg', '/dev/sda5']),
             mock.call(['lvextend', '--poolmetadatasize', '+1073741824B',
                        'vg/lv_thinpool']),
@@ -868,7 +877,7 @@ class TestGrowvols(base.BaseTestCase):
                        '--change-name=6:growvols', '/dev/dm-0']),
             mock.call(['multipath', '-r']),
             mock.call(['partprobe']),
-            mock.call(['pvcreate', '/dev/mapper/mpatha6']),
+            mock.call(['pvcreate', '-ff', '--yes', '/dev/mapper/mpatha6']),
             mock.call(['vgextend', 'vg', '/dev/mapper/mpatha6']),
             mock.call(['lvextend', '--poolmetadatasize', '+1073741824B',
                        'vg/lv_thinpool']),
